==> redwood-layout-testing-iosx64-0.10.0-sources.jar: commonMain/app/cash/redwood/layout/testing/RowValue.kt <==
@file:Suppress("DEPRECATION", "OVERRIDE_DEPRECATION")

package app.cash.redwood.layout.testing

import app.cash.redwood.Modifier
import app.cash.redwood.RedwoodCodegenApi
import app.cash.redwood.layout.api.Constraint
import app.cash.redwood.layout.api.CrossAxisAlignment
import app.cash.redwood.layout.api.MainAxisAlignment
import app.cash.redwood.layout.api.Overflow
import app.cash.redwood.layout.widget.RedwoodLayoutWidgetFactoryOwner
import app.cash.redwood.testing.WidgetValue
import app.cash.redwood.ui.Margin
import app.cash.redwood.widget.Widget
import app.cash.redwood.widget.WidgetSystem
import kotlin.Any
import kotlin.Boolean
import kotlin.Int
import kotlin.OptIn
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.listOf

public class RowValue(
  override val modifier: Modifier = Modifier,
  public val width: Constraint = Constraint.Wrap,
  public val height: Constraint = Constraint.Wrap,
  public val margin: Margin = Margin.Zero,
  public val overflow: Overflow = Overflow.Clip,
  public val horizontalAlignment: MainAxisAlignment = MainAxisAlignment.Start,
  public val verticalAlignment: CrossAxisAlignment = CrossAxisAlignment.Start,
  public val children: List<WidgetValue> = listOf(),
) : WidgetValue {
  override val childrenLists: List<List<WidgetValue>>
    get() = listOf(children)

  override fun equals(other: Any?): Boolean = other is RowValue &&
  other.modifier == modifier &&
  other.width == width &&
  other.height == height &&
  other.margin == margin &&
  other.overflow == overflow &&
  other.horizontalAlignment == horizontalAlignment &&
  other.verticalAlignment == verticalAlignment &&
  other.children == children

  override fun hashCode(): Int = listOf(modifier, width, height, margin, overflow,
      horizontalAlignment, verticalAlignment, children).hashCode()

  override fun toString(): String =
      """RowValue(modifier=$modifier, width=$width, height=$height, margin=$margin, overflow=$overflow, horizontalAlignment=$horizontalAlignment, verticalAlignment=$verticalAlignment, children=$children)"""

  @OptIn(RedwoodCodegenApi::class)
  override fun <W : Any> toWidget(widgetSystem: WidgetSystem<W>): Widget<W> {
    @Suppress("UNCHECKED_CAST") // Type parameter shared in generated code.
    val factoryOwner = widgetSystem as RedwoodLayoutWidgetFactoryOwner<W>
    val instance = factoryOwner.RedwoodLayout.Row()

    instance.width(width)
    instance.height(height)
    instance.margin(margin)
    instance.overflow(overflow)
    instance.horizontalAlignment(horizontalAlignment)
    instance.verticalAlignment(verticalAlignment)
    instance.modifier = modifier

    for ((index, child) in children.withIndex()) {
      instance.children.insert(index, child.toWidget(widgetSystem))
    }

    return instance
  }
}

==> redwood-layout-testing-iosx64-0.12.0-sources.jar: commonMain/app/cash/redwood/layout/testing/RowValue.kt <==
@file:Suppress("DEPRECATION", "OVERRIDE_DEPRECATION")

package app.cash.redwood.layout.testing

import app.cash.redwood.Modifier
import app.cash.redwood.RedwoodCodegenApi
import app.cash.redwood.layout.api.Constraint
import app.cash.redwood.layout.api.CrossAxisAlignment
import app.cash.redwood.layout.api.MainAxisAlignment
import app.cash.redwood.layout.api.Overflow
import app.cash.redwood.layout.widget.RedwoodLayoutWidgetFactoryOwner
import app.cash.redwood.testing.WidgetValue
import app.cash.redwood.testing.toDebugString
import app.cash.redwood.ui.Margin
import app.cash.redwood.widget.Widget
import app.cash.redwood.widget.WidgetSystem
import kotlin.Any
import kotlin.Boolean
import kotlin.Int
import kotlin.OptIn
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.collections.listOf

public class RowValue(
  override val modifier: Modifier = Modifier,
  public val width: Constraint = Constraint.Wrap,
  public val height: Constraint = Constraint.Wrap,
  public val margin: Margin = Margin.Zero,
  public val overflow: Overflow = Overflow.Clip,
  public val horizontalAlignment: MainAxisAlignment = MainAxisAlignment.Start,
  public val verticalAlignment: CrossAxisAlignment = CrossAxisAlignment.Start,
  public val children: List<WidgetValue> = listOf(),
) : WidgetValue {
  override val childrenLists: List<List<WidgetValue>>
    get() = listOf(children)

  override fun equals(other: Any?): Boolean = other is RowValue &&
  other.modifier == modifier &&
  other.width == width &&
  other.height == height &&
  other.margin == margin &&
  other.overflow == overflow &&
  other.horizontalAlignment == horizontalAlignment &&
  other.verticalAlignment == verticalAlignment &&
  other.children == children

  override fun hashCode(): Int = listOf(modifier, width, height, margin, overflow,
      horizontalAlignment, verticalAlignment, children).hashCode()

  override fun toString(): String =
      """RowValue(modifier=$modifier, width=$width, height=$height, margin=$margin, overflow=$overflow, horizontalAlignment=$horizontalAlignment, verticalAlignment=$verticalAlignment, children=$children)"""

  override fun toDebugString(): String = buildString {
    append("Row")
    append("""
        |(
        |  width = $width, 
        |  height = $height, 
        |  margin = $margin, 
        |  overflow = $overflow, 
        |  horizontalAlignment = $horizontalAlignment, 
        |  verticalAlignment = $verticalAlignment
        |""".trimMargin())
    append(")")
    append(" {")
    if (childrenLists[0].isNotEmpty()) {
      appendLine()
      append(childrenLists[0].toDebugString().prependIndent("  "))
      append("\n}")
    }
    else {
      append(" }")
    }
  }

  @OptIn(RedwoodCodegenApi::class)
  override fun <W : Any> toWidget(widgetSystem: WidgetSystem<W>): Widget<W> {
    @Suppress("UNCHECKED_CAST") // Type parameter shared in generated code.
    val factoryOwner = widgetSystem as RedwoodLayoutWidgetFactoryOwner<W>
    val instance = factoryOwner.RedwoodLayout.Row()

    instance.width(width)
    instance.height(height)
    instance.margin(margin)
    instance.overflow(overflow)
    instance.horizontalAlignment(horizontalAlignment)
    instance.verticalAlignment(verticalAlignment)
    instance.modifier = modifier

    for ((index, child) in children.withIndex()) {
      instance.children.insert(index, child.toWidget(widgetSystem))
    }

    return instance
  }
}
